@@ -21,6 +21,21 @@ require_once ('application/helpers/safe_helper.php');
 safe_require_class('safe_service_class');
 safe_module_require_class('fs', 'application');
 
+class Fs_snort_update_sip_profile_configuration_class extends Safe_configuration_user_class
+{
+    public function __construct($port_list)
+    {
+        parent::__construct('Intrusion Detection', Safe_configuration_class::CFG_UPDATE, $port_list);
+    }
+    public function run($node)
+    {
+        return $node->execute('sudo ' . $node->configuration_manager()->directory('binary') . '/snort-update-config --ports "' . implode(',', $this->data()) . '"');
+    }
+    public function file_name()
+    {
+        return 'Intrusion Detection - Port List = ' . implode(',', $this->data());
+    }
+}
 class Fs_sip_module_class extends Fs_module_class
 {
     protected $_obj_base_path = '';
@@ -345,6 +360,11 @@ class Fs_sip_module_class extends Fs_module_class
                 if (!$this->_write_sip_core($config_manager, $profile)) return false;
             }
         }
+        // Other deps
+        if(!$obj_type || 'profile' == $obj_type) {
+            // Update snort
+            $this->_update_intrusion_detection($config_manager);
+        }
 
         // Handle deleted
         $this->_handle_deleted_trunks($config_manager);
@@ -352,6 +372,19 @@ class Fs_sip_module_class extends Fs_module_class
 
         return true;
     }
+    private function _update_intrusion_detection($config_manager)
+    {
+        $port_list = array();
+        $sip_profiles = $this->profiles();
+        foreach ($sip_profiles as $sip) {
+            $sip->get_sip_transport_info($trans, $port);
+            if ($trans != 'tls') {
+                if (FALSE == in_array($port, $port_list)) $port_list[] = $port;
+            }
+        }
+        $config_manager->add_config(new Fs_snort_update_sip_profile_configuration_class($port_list));
+    }
+
     protected function _handle_deleted_trunks(&$config_manager)
     {
         //Handle Deleted SIP Trunk
