@@ -184,6 +184,13 @@ class Fs_sip_profile_class extends Safe_configurable_object_class {
     $this->add_enum_field('notify-refer-on-final-rsp', 'Notify REFER on Final Response', 'dropdown', 'false', $this->enable_disable_enum());
     $this->set_field_help('notify-refer-on-final-rsp','Whether to determine REFER result base on final response. This applies only if a new call leg is created to the referee.');
 
+    $this->add_enum_field('rtp-auto-local-port-renew-on-reinvite', 'Renew RTP Port On ReInvite', 'dropdown', 'false', $this->enable_disable_enum());
+    $this->set_field_help('rtp-auto-local-port-renew-on-reinvite',
+      array(
+        'Enable/Disable Automatic Local RTP Port Renewal On ReInvite.',
+        'If enabled, when a new SDP offer is received in connected state and if media line remote IP or Port has been changed, a new local port is assigned for the RTP stream.'
+        )
+    );
 
     // Add Interoperability category
     $this->set_field_category('enable-100rel','Interoperability');
