@@ -185,13 +185,13 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
         // Set the basic data
         $data['page_title'] = 'Update Media Interfaces';
         if(Safe_service_class::STATUS_RUNNING == $this->_the_app->status()){
-            $data['message'] = 'Cannot Update Media Interfaces while '.$this->_the_app->description().' is Running.';
+            $data['message'] = 'Cannot update media interfaces while '.$this->_the_app->description().' is running.';
             $data['message_type'] = 'alert';
             //for ajax json data return
             $data['result'] = false;
             $data['action_url'] = $this->router->fetch_class();
         }else{
-            $data['message'] = 'Interfaces Update process will delete current configuration!';
+            $data['message'] = 'Interface update process will delete current configuration!';
             $data['message_type'] = 'alert';
             //for ajax json data return
             $data['result'] = true;
@@ -223,11 +223,11 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
     {
         // Set the basic data
         $data['page_title'] = 'Media Server Interfaces detection';
-        $data['page_summary'] = 'This page allows Updating Media Server Interfaces.';
+        $data['page_summary'] = 'This page allows updating media server interfaces.';
         $data['page_large_icon'] = '/images/icons/32x32/icon-network.png';
         $data['page_small_icon'] = '/images/icons/16x16/icon-network.png';
         // Display wait
-        $data['wait_message'] = '</br><b>Updating Media Server Interfaces...</b><br/>This may take several minutes</br>&nbsp;';
+        $data['wait_message'] = '</br><b>Updating media server interfaces ...</b><br/>This may take several minutes</br>&nbsp;';
         $data['timeout_sec'] = 600;
         $this->load->view("safe_header", $data);
         $this->load->view("safe_confirm_dialog", $data);
