@@ -251,6 +251,24 @@ function safe_form_with_submit_button($message, $action, $button_label, $button_
     <form action="' . $action . '" method="' . $method . '" enctype="multipart/form-data">' . $message . $extra_fields . '<input ' . $button_name . $style . ' value="' . $button_label . '" type="submit" class="ui-state-default ui-corner-all">
     </form>';
 }
+function safe_form_with_submit_button_confirm($message, $action, $button_label, $button_value = NULL, $method = 'post', $style = NULL, $hidden_fields = array())
+{
+    if (isset($button_value)) $button_name = ' name="' . $button_value . '" ';
+    else $button_name = '';
+    if (isset($style)) $style.= ' style="' . $style . '" ';
+    else $style = "";
+    $extra_fields = "";
+    foreach ($hidden_fields as $k => $v) {
+        $extra_fields.= '<input type="hidden" name="' . $k . '" value="' . $v . '"/>';
+    }
+    return '
+        <form action="' . $action . '" method="'
+        . $method . '" enctype="multipart/form-data">'
+        . $message . $extra_fields . '<input '
+        . $button_name . $style . ' value="' . $button_label
+        . '" type="button" onclick="safe_handle_confirm_button(this);" class="ui-state-default ui-corner-all">
+    </form>';
+}
 function safe_button_click($name, $value, $url, $id = '', $attributes = NULL)
 {
     if (!isset($attributes)) {
@@ -1149,6 +1167,46 @@ function Safe_format_xml($xml)
         }
         return (substr($ip,0,$mask) === substr($s_ip,0,$mask)) ;
     }
+    function safe_format_button($buttons){
+    //delete[unbind]:confirm
+        $line_buttons = explode('|', $buttons);
+        $tmp_buttons = array();
+        foreach($line_buttons as $button){
+            
+            if(strpos($button, ":") === false){
+                $button_type = 'button';
+            }else{
+                list($button,$button_type) = explode(':', $button);
+            }
+            $first=strpos($button, "[");
+            $next=strpos($button, "]");
+            if( $first !== false &&  $next !== false &&  ($first < $next) ){
+                list($button_id, $button_value) = explode('[', $button);
+                list($button_value) = explode(']', $button_value);
+            }else{
+                $button_id = $button;
+                $button_value = $button;
+            }
+            $button_id = strtolower(trim($button_id));
+            $tmp_buttons[$button_id]['id']=$button_id;
+            $tmp_buttons[$button_id]['value']=$button_value;
+            $tmp_buttons[$button_id]['type']=trim($button_type);
+        }
+        return $tmp_buttons;
+    }
+function safe_format_bytes($bytes, $precision = 2) { 
+    $units = array('B', 'KB', 'MB', 'GB', 'TB'); 
+
+    $bytes = max($bytes, 0); 
+    $pow = floor(($bytes ? log($bytes) : 0) / log(1024)); 
+    $pow = min($pow, count($units) - 1); 
+
+    // Uncomment one of the following alternatives
+    // $bytes /= pow(1024, $pow);
+    $bytes /= (1 << (10 * $pow)); 
+
+    return round($bytes, $precision) . ' ' . $units[$pow]; 
+} 
 
 /* End of file safe_helper.php */
             
