@@ -553,8 +553,15 @@ class Safe_form_class
                 else $temp_conf['class'] = ' safe_' . $curr_conf['type'];
                 $temp_conf['type'] = 'text';
             default:
-                if (isset($curr_conf['disabled'])) return $prefix . form_input($temp_conf, '', $curr_conf['disabled']) . $suffix;
-                else return $prefix . form_input($temp_conf) . $suffix;
+                $_extra = '';
+                if('password' == $curr_conf['type']){
+                    $_extra = ' autocomplete="off"';
+                }
+                if (isset($curr_conf['disabled'])){
+                    return $prefix . form_input($temp_conf, '', $curr_conf['disabled']) . $suffix;
+                } else{
+                    return $prefix . form_input($temp_conf, '', $_extra) . $suffix;
+                }
             } // end of switch
             
         }
