@@ -637,31 +637,39 @@ class Safe_object_class
      * @return $array
      *                			Array of aggregated configs
      */
+    private $_agg_objects_cache = array();
     public function get_aggregate_objects($type, $all=false)
     {
         $definition = $this->_aggr_obj_type[$type];
         // Do we have base path ?
         if($definition['base_path']) {
-            // Re-create object list
-            $objects = Safe_object_serializer_class::get_serializer()->find_objects($definition['base_path']);
-            foreach ($objects as $k => $v) {
-                $obj = new $v['class']($this->node(), $definition['base_path'], $k);
-                $obj->configure();
-                $obj->synch();
-                $objects[$k] = $obj;
-            }
-            // Check if we want the deleted objects as well
-            if($all){
+            // Check objects cache (or requesting all)
+            if(!$this->_agg_objects_cache[$type] || $this->_agg_objects_cache[$type]['all'] != $all){
                 // Re-create object list
-                $deleted = Safe_object_serializer_class::get_serializer()->find_deleted_objects($definition['base_path']);
-                foreach ($deleted as $k => $v) {
+                $objects = Safe_object_serializer_class::get_serializer()->find_objects($definition['base_path']);
+                foreach ($objects as $k => $v) {
                     $obj = new $v['class']($this->node(), $definition['base_path'], $k);
                     $obj->configure();
-                    $obj->unserialize();
+                    $obj->synch();
                     $objects[$k] = $obj;
                 }
+                // Check if we want the deleted objects as well
+                if($all){
+                    // Re-create object list
+                    $deleted = Safe_object_serializer_class::get_serializer()->find_deleted_objects($definition['base_path']);
+                    foreach ($deleted as $k => $v) {
+                        $obj = new $v['class']($this->node(), $definition['base_path'], $k);
+                        $obj->configure();
+                        $obj->unserialize();
+                        $objects[$k] = $obj;
+                    }
+                }
+                // Store in cache
+                $this->_agg_objects_cache[$type]['objects'] = $objects;
+                $this->_agg_objects_cache[$type]['all'] = $all;
             }
-            return $objects;
+            // Use cache
+            return $this->_agg_objects_cache[$type]['objects'];
         } else if (method_exists($this, 'api_retrieve_'.$type)) {
             return call_user_func(array(
                 $this,
@@ -675,6 +683,44 @@ class Safe_object_class
         }
         return array();
     }
+    
+    /**
+     * @brief clear objs in cache (so it can be regenerate from db )
+     *
+     * @param[in out] $type
+     *
+     * @return
+     */
+    protected function clear_cache($type = null)
+    {
+        //clear objs in cache
+        if ($type){
+            if($this->_agg_objects_cache[$type]){
+                unset($this->_agg_objects_cache[$type]);
+            }
+        }else{
+            $this->_agg_objects_cache = array();
+        }
+    }
+    /**
+     * @brief Check if specified aggregate object can be created
+     *
+     * @param[in out] $_type
+     * @param[in out] $name
+     * @param[in out] $reason)
+     *
+     * @return 
+     */
+    public function can_create_aggregate_object($type, $name, &$reason="")
+    {
+        // Default implementation - Check object name exists
+        $objs = $this->get_aggregate_objects($type);
+        if($objs[$name]){
+            $reason = "Already exists";
+            return false;
+        }
+        return true;
+    }
     public function create_aggregate_object($type, $name='default')
     {
         if('configuration'==$type && $this->config()) {
