@@ -164,7 +164,7 @@ function safe_handle_create_button(button_obj){
 			  
 		  },
 		  error:function(xhr){
-			safe_message_box('An error occured:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
+			safe_message_box('An error occurred:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
 		  }
 		});
 }
@@ -205,7 +205,7 @@ function safe_handle_confirm_button(button_obj){
 			  
 		  },
 		  error:function(xhr){
-			safe_message_box('An error occured:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
+			safe_message_box('An error occurred:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
 		  }
 		});
 }
@@ -273,14 +273,14 @@ function safe_confirmation_box(title, content, url_ok, url_cancel, ok_method, ca
 	            				  if (typeof rs.redirect_url !== 'undefined'){
 	            					  window.location = rs.redirect_url;
 	            				  }else{
-	            					  safe_message_box('An error occured:', safe_message_style("Redirect url undefined.",'alert'));
+	            					  safe_message_box('An error occurred:', safe_message_style("Redirect url undefined.",'alert'));
 	            				  }
 	            			  }else{
 	            				  safe_message_box(rs.page_title,safe_message_style(rs.message,rs.message_type));
 	            			  }
 	            		  },
 	            		  error:function(xhr){
-	            			  safe_message_box('An error occured:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
+	            			  safe_message_box('An error occurred:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
 	            		  }
 	            		});
 	                return false;
@@ -295,7 +295,7 @@ function safe_confirmation_box(title, content, url_ok, url_cancel, ok_method, ca
 			}
 		});
 	}else{
-		safe_message_box('An error occured:', safe_message_style("Parameter missing, Open the confirmation box failed",'alert'));
+		safe_message_box('An error occurred:', safe_message_style("Parameter missing, Open the confirmation box failed",'alert'));
 		return false;
 	}
 }
@@ -488,7 +488,7 @@ function safe_create_box(title, content, url_ok, url_cancel, ok_method, cancel_m
 							    	$("#safe_progress_bar .ui-progressbar-value").animate({width: percentComplete+"%"},50);
 							        $("#safe_progress_bar").find("#percent").html(percentComplete + '%')
 							        if(percentComplete >= 100){
-							        	upload_processing_ui.find("#content").html('File Uploaded successfully! System processing...');
+							        	upload_processing_ui.find("#content").html('File Uploaded Successfully! System Processing ...');
 							        }
 							    },
 						        success:       function(rs){
@@ -498,7 +498,7 @@ function safe_create_box(title, content, url_ok, url_cancel, ok_method, cancel_m
 			            				  if (typeof rs.redirect_url !== 'undefined'){
 			            					  window.location = rs.redirect_url;
 			            				  }else{
-			            					  safe_message_box('An error occured:', safe_message_style("Redirect url undefined.",'alert'));
+			            					  safe_message_box('An error occurred:', safe_message_style("Redirect url undefined.",'alert'));
 			            				  }
 			            			  }else{
 			            				  //add fail
@@ -531,7 +531,7 @@ function safe_create_box(title, content, url_ok, url_cancel, ok_method, cancel_m
 			            			  }
 			            		},  // post-submit callback
 			            		error:function(xhr){
-			              			safe_message_box('An error occured:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
+			              			safe_message_box('An error occurred:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
 			              		},
 			              		complete: function(xhr) {
 			              				//status.html(xhr.responseText);
@@ -572,7 +572,7 @@ function safe_create_box(title, content, url_ok, url_cancel, ok_method, cancel_m
 		            				  if (typeof rs.redirect_url !== 'undefined'){
 		            					  window.location = rs.redirect_url;
 		            				  }else{
-		            					  safe_message_box('An error occured:', safe_message_style("Redirect url undefined.",'alert'));
+		            					  safe_message_box('An error occurred:', safe_message_style("Redirect url undefined.",'alert'));
 		            				  }
 		            			  }else{
 		            				  //add fail
@@ -605,7 +605,7 @@ function safe_create_box(title, content, url_ok, url_cancel, ok_method, cancel_m
 		            			  }
 		            		  },
 		            		  error:function(xhr){
-		            			  safe_message_box('An error occured:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
+		            			  safe_message_box('An error occurred:', safe_message_style(xhr.status + " " + xhr.statusText,'alert'));
 		            		  }
 		            		});
 					}
@@ -624,7 +624,7 @@ function safe_create_box(title, content, url_ok, url_cancel, ok_method, cancel_m
 	          ]
 		});
 	}else{
-		safe_message_box('An error occured:', safe_message_style("Parameter missing, Open the confirmation box failed.",'alert'));
+		safe_message_box('An error occurred:', safe_message_style("Parameter missing, Open the confirmation box failed.",'alert'));
 		return false;
 	}
 }
