@@ -829,7 +829,7 @@ class Sng_data_manager extends Safe_CI_Controller
         }
         if($data['notif_error'] == null){
             $data['message_type'] = 'notice';
-            $data['message'] ='File Uploaded successfully.';
+            $data['message'] ='File Uploaded Successfully.';
             $data['result'] = true;
             $data['redirect_url'] = $back_url;
         }else{
